# Changelog

<!-- version list -->

## v2.2.0 (2025-10-23)

### Chores

- Remove lockfile from version control
  ([`0229547`](https://github.com/Promptly-Technologies-LLC/etielle/commit/022954758ee7e72cb42909bb8bdab8ebff030a6e))

### Features

- New ConstructorBuilder for ORMs
  ([`977b0a0`](https://github.com/Promptly-Technologies-LLC/etielle/commit/977b0a0e866cadaae5a7cb2ef343dcfc117c2f84))


## v2.1.0 (2025-10-20)

### Documentation

- Clarify field selector docs
  ([`cb90959`](https://github.com/Promptly-Technologies-LLC/etielle/commit/cb90959941ab9ede524e33f4293570c7b72f7cfa))

- Cross-linking, user-friendliness
  ([`acb8b87`](https://github.com/Promptly-Technologies-LLC/etielle/commit/acb8b871912523926cdf0816069d62e55125b8fb))

- Improve clarity of README
  ([`dbc75c2`](https://github.com/Promptly-Technologies-LLC/etielle/commit/dbc75c2e24a1fb111a04b18b3b3b203ba5feb477))

- More detailed emission guide
  ([`782ab62`](https://github.com/Promptly-Technologies-LLC/etielle/commit/782ab6246c3518f8e543a408f335aa7722467d2b))

### Features

- Consolidate/enhance adapter documentation
  ([`e6df5ed`](https://github.com/Promptly-Technologies-LLC/etielle/commit/e6df5edc5fa283c7411d9f909841b07ed60cf431))


## v2.0.0 (2025-10-19)

### Bug Fixes

- Make release workflow ff after publish
  ([`506d3c8`](https://github.com/Promptly-Technologies-LLC/etielle/commit/506d3c86390bbac20cb36ef7fcbbd0b6d97a3b30))

### Documentation

- Add backticks around code
  ([`e251f3f`](https://github.com/Promptly-Technologies-LLC/etielle/commit/e251f3f5c24b6f9965b20a3fc006224e60b0fab0))

- All documentation code runs
  ([`61dbb24`](https://github.com/Promptly-Technologies-LLC/etielle/commit/61dbb245bdff603dd37b9240e7e0ec74a2241229))

- Documentation website
  ([`8019c14`](https://github.com/Promptly-Technologies-LLC/etielle/commit/8019c1489f710f70fcafdf08c723a1a9929d840d))

- Example code triggers errors
  ([`b12093e`](https://github.com/Promptly-Technologies-LLC/etielle/commit/b12093ef19389e5663785a460f082aa8c2e861fd))

- Fix header text color
  ([`69ab9d4`](https://github.com/Promptly-Technologies-LLC/etielle/commit/69ab9d44e73725c5482e9132259aba836a86b88a))

- Print mapping result
  ([`1ef1164`](https://github.com/Promptly-Technologies-LLC/etielle/commit/1ef1164a844a2045163be515175da3a3b61de645))

### Features

- Simplify iteration API
  ([`25e1c17`](https://github.com/Promptly-Technologies-LLC/etielle/commit/25e1c177ef497880f912b5c9770e01718298138d))


## v1.4.0 (2025-10-15)

### Features

- Sqlalchemy adapter
  ([`3ac07a1`](https://github.com/Promptly-Technologies-LLC/etielle/commit/3ac07a135d487d842552788d032dcbf0cf86757e))


## v1.3.0 (2025-10-14)

### Features

- Mutation-based emit
  ([`21dbbe6`](https://github.com/Promptly-Technologies-LLC/etielle/commit/21dbbe60c4feae493eec00c675dc0f698069d969))


## v1.2.0 (2025-10-14)

### Features

- Error reporting
  ([`10657ec`](https://github.com/Promptly-Technologies-LLC/etielle/commit/10657ec161b6f09c8b95e5f4ae952d8f2bd70f39))

- Instance emission adapter
  ([`4c02de0`](https://github.com/Promptly-Technologies-LLC/etielle/commit/4c02de0a87fae2309f8c4e3e0662452c31f338ca))


## v1.1.0 (2025-10-14)

### Features

- Implement field selectors API
  ([`e099dbe`](https://github.com/Promptly-Technologies-LLC/etielle/commit/e099dbe9dda503fc745370dcfe9850918641ac35))


## v1.0.6 (2025-10-14)

### Bug Fixes

- Configure pyproject version stamping
  ([`49c4e07`](https://github.com/Promptly-Technologies-LLC/etielle/commit/49c4e07af4cf72c446c3847399abe776e515ab85))


## v1.0.5 (2025-10-14)

### Bug Fixes

- Make release dependent on test
  ([`b377958`](https://github.com/Promptly-Technologies-LLC/etielle/commit/b37795886a41674c677bc13e2df676fe42effc6f))


## v1.0.4 (2025-10-14)

### Bug Fixes

- Correctly use PyPi env for publish job
  ([`2dd6cea`](https://github.com/Promptly-Technologies-LLC/etielle/commit/2dd6cea8ff3fd99a5ac64d627721bcdac394750a))


## v1.0.3 (2025-10-14)

### Bug Fixes

- Run build in PSR container
  ([`6c359c6`](https://github.com/Promptly-Technologies-LLC/etielle/commit/6c359c6bc281118068fe1b41a6f5e8db4d8cad87))


## v1.0.2 (2025-10-14)

### Bug Fixes

- Restore build step
  ([`4250642`](https://github.com/Promptly-Technologies-LLC/etielle/commit/42506424365d86a321acc044e0363840da0dc6f3))


## v1.0.1 (2025-10-14)

### Bug Fixes

- Gate artifact upload
  ([`5e5bda1`](https://github.com/Promptly-Technologies-LLC/etielle/commit/5e5bda1ee36397b3913ab3a1cbc58b28e5d3f458))


## v1.0.0 (2025-10-14)

### Bug Fixes

- Actions-compliant root path
  ([`251d553`](https://github.com/Promptly-Technologies-LLC/etielle/commit/251d5530f61aaef988f0ed23bcf312e85f3a822c))

- Add missing semantic release config
  ([`f6235d4`](https://github.com/Promptly-Technologies-LLC/etielle/commit/f6235d449d76a8ae9d6788d494f08d44a612fd10))

- Semantic release version mismatch
  ([`3dbf9a0`](https://github.com/Promptly-Technologies-LLC/etielle/commit/3dbf9a0559a47e59efbf23d9ed4a935422283647))

- Use semantic release's built-in committer
  ([`6681c31`](https://github.com/Promptly-Technologies-LLC/etielle/commit/6681c31c30c29f835998ec1a77d39d752e64c52a))
